# Change logs of cx-studio

### v0.2.1.5

- FFmpeg 同步版本已经可以使用了

### v0.2.1.4

- PathUtils.quote now supports `escape` mode.
- Rewrite ffmpeg(thread safe version).

### v0.2.1.3

- rewrite DataPackage with proper annotations.
- `DataPackage` now supports index of list as key.
